.. _spkg_webcolors:

webcolors: Library for working with the color formats defined by HTML and CSS
=============================================================================

Description
-----------

Library for working with the color formats defined by HTML and CSS

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/webcolors/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.13

version_requirements.txt::

    webcolors

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install webcolors

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i webcolors

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-webcolors


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
